env

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2024 License: MPL-2.0 Imports: 2 Imported by: 1

Documentation

Overview

Package env provides utilities for working with environment variables.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Default

func Default() []string

Default returns a minimal list of env vars that will be inherited by the shell process. This is used to avoid leaking sensitive information.

func FilterSafe

func FilterSafe(env []string) []string

FilterSafe filters the given client environment variables into a safe subset that can be passed to the server, includes TERM, LANG, and LC_*.

Types

This section is empty.

Jump to