Documentation
¶
Overview ¶
Package env provides utilities for working with environment variables.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Default ¶
func Default() []string
Default returns a minimal list of env vars that will be inherited by the shell process. This is used to avoid leaking sensitive information.
func FilterSafe ¶
FilterSafe filters the given client environment variables into a safe subset that can be passed to the server, includes TERM, LANG, and LC_*.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.